//	キャラクタLCD-I2C化アダプタ Ver.2 動作デモ
//	『昼夜逆転』工作室	http://jsdiy.webcrow.jp

/*
【ポート対応】	ATmega328P	x:存在しない(PC6はRESET) -:空き
bit		7	6	5	4	3	2	1	0
portB	-	- SCK MISO MOSI	-	-	-
portC	x	*	SCL	SDA	-	-	-	-		TWI(I2C)/プルアップ抵抗:10kΩ
portD	-	-	-	-	-	-	-	-

【ATmega328P】
|543210---54321|
|CCCCCCGRVBBBBB|
>              |
|CDDDDDVGBBDDDB|
|601234--675670|

【ヒューズビット】(ftavrw.exe -rf)	※工場出荷設定は Low:01100010(62), Hi:11011001(D9)
Low: 01100010 (62)
     ||||++++-- CKSEL[3:0] システムクロック選択
     ||++-- SUT[1:0] 起動時間
     |+-- CKOUT (0:PB0にシステムクロックを出力)
     +-- CKDIV8 クロック分周初期値 (1:1/1, 0:1/8)

High:11-11001 (D9)
     |||||||+-- BOOTRST ※データシート参照
     |||||++-- BOOTSZ[1:0] ※データシート参照
     ||||+-- EESAVE (消去でEEPROMを 1:消去, 0:保持)
     |||+-- WDTON (1:WDT通常動作, 0:WDT常時ON)
     ||+-- SPIEN (1:ISP禁止, 0:ISP許可) ※Parallel時のみ
     |+-- DWEN (On-Chipデバッグ 1:無効, 0:有効)
     +-- RSTDISBL (RESETピン 1:有効, 0:無効(PC6))

Ext: -----111 (FF)
          +++-- BODLEVEL[2:0] (111:無, 110:1.8V, 101:2.7V, 100:4.3V)
*/
/*
【ビルド環境】
Atmel Studio 7 (Version: 7.0.1417 - )
ATmega328P/1MHz（内蔵8MHz/8分周）	最適化: -Os

【更新履歴】
2017/09/07	v1.00	初版
	Program Memory Usage 	:	772 bytes   2.4 % Full
	Data Memory Usage 		:	8 bytes   0.4 % Full
*/

#include <avr/io.h>
#include <avr/pgmspace.h>
#include <util/delay.h>
#include "twilib.h"
#include "twiclcd/I2cCharLcdLib.h"

int main(void)
{
	uint8_t i;
	
	for (i = 0; i < 15; i++){ _delay_ms(100); }	//周辺機器の立ち上がりを待つ(1～2秒)
	
	TWI_MasterInit();

	I2CLCD_Init(I2CLCD_DEFAULT_SLA, 16, 2);
	I2CLCD_SetLineMode(LCD_LINEMODE_COMBINE | LCD_LINEMODE_OVERWRITE, LCD_CURSOR_ON);
	
	I2CLCD_PutChar('M');
	I2CLCD_PutByte(0xFF);
	I2CLCD_PutWord(0x1A2B);
	I2CLCD_PutUInt(65535);
	I2CLCD_PutInt(-32768);
	I2CLCD_PutString("abcdef");
	I2CLCD_PutStringP(PSTR("ABCDEDF"));
	for (i = 0; i < 30; i++){ _delay_ms(100); }	//3秒待つ（上書きデモが確実に見えるように）
	I2CLCD_PutStringP(PSTR("0123456789opqrst#UVWXYZ9876543210"));

	
	return 0;
}
